@@ -1,5 +1,6 @@
 #' @include zzz.R
 #' @include generics.R
+#' @include graph.R
 #' @importFrom methods new slot slot<-
 #'
 NULL
@@ -8,6 +9,8 @@ NULL
 # Class definitions
 #%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
+setClassUnion(name = 'AnyMatrix', members = c("matrix", "dgCMatrix"))
+
 #' The Assay Class
 #'
 #' The Assay object is the basic unit of Seurat; each Assay stores raw,
@@ -67,6 +70,7 @@ Assay <- setClass(
 #' new object with a lower cutoff.
 #' @param min.features Include cells where at least this many features are
 #' detected.
+#' @param check.matrix Check counts matrix for NA, NaN, Inf, and non-integer values
 #' @param ... Arguments passed to \code{\link{as.sparse}}
 #'
 #' @return A \code{\link{Assay}} object
@@ -93,6 +97,7 @@ CreateAssayObject <- function(
   data,
   min.cells = 0,
   min.features = 0,
+  check.matrix = FALSE,
   ...
 ) {
   if (missing(x = counts) && missing(x = data)) {
@@ -127,7 +132,14 @@ CreateAssayObject <- function(
       stop("No feature names (rownames) names present in the input matrix")
     }
     if (!inherits(x = counts, what = 'dgCMatrix')) {
-      counts <- as.sparse(x = counts, ...)
+      if (inherits(x = counts, what = "data.frame")) {
+        counts <- as.sparse(x = counts, ...)
+      } else {
+        counts <- as.sparse(x = counts)
+      }
+    }
+    if (isTRUE(x = check.matrix)) {
+      CheckMatrix(object = counts)
     }
     # Filter based on min.features
     if (min.features > 0) {
